jep
Date: 2015-08-04

# Package jep

- Interface Summary
  Interface | Description
  --- | ---
  ClassEnquirer | Interface to enquire if a name is available to be imported from Java.

- Class Summary
  Class | Description
  --- | ---
  ClassList | A singleton that searches for loaded classes from the JRE and the Java classpath.
  InvocationHandler | Handle Proxy method calls.
  Jep | Embeds CPython in Java.
  JepScriptEngine | Implements `ScriptEngine`
  JepScriptEngineFactory | Implements `ScriptEngineFactory`
  NamingConventionClassEnquirer | A simple `ClassEnquirer` to see if the package/class to be imported in a Python sub-interpreter should be considered as a Java package/class.
  NDArray<T> | Represents a numpy.ndarray in Java.
  Proxy | Extends java.lang.reflect.Proxy for callbacks.
  Run | Executes a Python script in a Jep sub-interpreter.
  Util | Utility functions

- Exception Summary
  Exception | Description
  --- | ---
  JepException | JepException - it happens.